import sys, serial
import numpy as np
from time import sleep
from collections import deque
import matplotlib.pyplot as plt
import matplotlib.animation as animation

ser = serial.Serial(port='COM3', baudrate=9600, bytesize=serial.EIGHTBITS, parity=serial.PARITY_EVEN, stopbits=1, timeout=2)

# plot class
class AnalogPlot:
  # constr
  def __init__(self, strPort, maxLen):
      # open serial port
      self.ser = strPort
      self.time = 0
      self.ax = deque([0.0]*maxLen)
      self.ay = deque([0.0]*maxLen)
      self.maxLen = maxLen
      self.d = 0

  # add to buffer
  def addToBuf(self, buf, val):
      if len(buf) < self.maxLen:
          buf.append(val)
      else:
          buf.pop()
          buf.appendleft(val)

  # add data
  def add(self, data):
      assert(len(data) == 2)
      self.addToBuf(self.ax, data[0])
      self.addToBuf(self.ay, data[1])

# update plot
  def update(self, frameNum, a0, a1):
      try:
          print('update')
          list = []
          data = []
          for c in ser.readline():
              list.append(chr(c))
          list.remove(list[-1])
          signal = ''.join(list);
          self.time += 2
          data.append(int(signal))
          data.append(self.time)
          print(data)
          if(len(data) == 2):
              self.add(data)
              a0.set_data(range(self.maxLen), self.ax)
              a1.set_data(range(self.maxLen), self.ay)
      except KeyboardInterrupt:
           print('exiting')

      return a0

analogPlot = AnalogPlot(ser, 100)

print('plotting data...')

# set up animation
fig = plt.figure()
ax = plt.axes(xlim=(0, 100), ylim=(0, 1000))
a0, = ax.plot([], [])
a1, = ax.plot([], [])
anim = animation.FuncAnimation(fig, analogPlot.update,
                               fargs=(a0, a1),
                               interval=20)

# show plot
plt.show()
